==> keyclic_sdk_api-1.38.7.tar.gz: lib/model/activity.dart <==
part of keyclic_sdk_api.api;

class Activity {
  String actor = null;

  String message = null;

  String object = null;

  String verb = null;

  String origin = null;

  String title = null;

  DateTime time = null;

  Activity();

  @override
  String toString() {
    return 'Activity[actor=$actor, message=$message, object=$object, verb=$verb, origin=$origin, title=$title, time=$time, ]';
  }

  Activity.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    actor = json['actor'];
    message = json['message'];
    object = json['object'];
    verb = json['verb'];
    origin = json['origin'];
    title = json['title'];
    time = json['time'] == null ? null : DateTime.parse(json['time']);
    if (time.isUtc == false) {
      time = DateTime.parse('${time.toIso8601String()}Z');
    }
  }

  Map<String, dynamic> toJson() {
    return {
      'actor': actor,
      'message': message,
      'object': object,
      'verb': verb,
      'origin': origin,
      'title': title,
      'time': time == null ? '' : time.toUtc().toIso8601String(),
    };
  }

  static List<Activity> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<Activity>()
        : json.map((value) => new Activity.fromJson(value)).toList();
  }

  static Map<String, Activity> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, Activity>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new Activity.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.38.8.tar.gz: lib/model/activity.dart <==
part of keyclic_sdk_api.api;

class Activity {
  String actor = null;

  String message = null;

  String object = null;

  String verb = null;

  String origin = null;

  String title = null;

  DateTime time = null;

  Activity();

  @override
  String toString() {
    return 'Activity[actor=$actor, message=$message, object=$object, verb=$verb, origin=$origin, title=$title, time=$time, ]';
  }

  Activity.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    actor = json['actor'];
    message = json['message'];
    object = json['object'];
    verb = json['verb'];
    origin = json['origin'];
    title = json['title'];
    time = json['time'] == null ? null : DateTime.parse(json['time']);
    if (time is DateTime && time.isUtc == false) {
      time = DateTime.parse('${time.toIso8601String()}Z');
    }
  }

  Map<String, dynamic> toJson() {
    return {
      'actor': actor,
      'message': message,
      'object': object,
      'verb': verb,
      'origin': origin,
      'title': title,
      'time': time == null ? '' : time.toUtc().toIso8601String(),
    };
  }

  static List<Activity> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<Activity>()
        : json.map((value) => new Activity.fromJson(value)).toList();
  }

  static Map<String, Activity> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, Activity>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new Activity.fromJson(value));
    }
    return map;
  }
}
